""" Menu scene. """

import os

import pygame.locals as pgl

from .base import BaseScene
from ..events import SceneChangeEvent
from ..widgets import TextButton
from ..loader import loader


class LoadLevelScene(BaseScene):

    def _list_stations(self):
        station_path = loader.full_path("stations")
        files = [f for f in os.listdir(station_path) if f.endswith(".json")]
        files.sort()
        return [loader.load_station(f) for f in files]

    def enter(self, gamestate):
        """Construct list of stations"""
        height = 50
        width = 30
        self._buttons = []
        for station in self._list_stations():
            title = station["config"]["name"]
            pos = (width, height)
            button = TextButton(title, (255, 255, 255), None, pos)
            button.station = station
            if width < 400:
                width += 350
            else:
                width = 30
                height += button.get_height() + 20
            self._buttons.append(button)

    def render(self, surface, gamestate):
        surface.fill((0, 128, 128))
        for button in self._buttons:
            button.render(surface)

    def _get_pressed(self, ev):
        for button in self._buttons:
            if button.pressed(ev):
                return button
        return None

    def _do_load(self, station, gamestate):
        from .day import DayScene
        print "Loading station", station["config"]["name"]
        gamestate.set_station(station)
        SceneChangeEvent.post(scene=DayScene())

    def event(self, ev, gamestate):
        if ev.type == pgl.KEYDOWN:
            if ev.key == pgl.K_l:
                self._do_load("station_alpha.json", gamestate)
        elif ev.type == pgl.MOUSEBUTTONDOWN:
            pressed = self._get_pressed(ev)
            if pressed:
                self._do_load(pressed.station, gamestate)
