""" Menu scene. """

import pygame.locals as pgl

from .base import BaseScene
from ..events import QuitEvent, SceneChangeEvent
from ..loader import loader
from ..constants import FONTS
from ..widgets import TextButton


class MenuScene(BaseScene):
    def enter(self, gamestate):
        if gamestate.station is None:
            print "Loading Station Alpha ..."
            gamestate.set_station(loader.load_station("station-alpha.json"))
        font_title = loader.load_font(FONTS['bold'], size=32)
        self._title = font_title.render('A Game with a title', True,
                                        (255, 255, 255))
        self._menu = [
            TextButton("Load Level", (255, 255, 255), name='load level'),
            TextButton("Start Game (Day)", (255, 255, 255), name='start game'),
            TextButton("Load Saved Game", (255, 255, 255), name='load game'),
            TextButton("Help", (255, 255, 255), name='help'),
        ]

    def render(self, surface, gamestate):
        surface.fill((0, 128, 0))

        pos = ((surface.get_width() - self._title.get_width()) / 2, 50)
        surface.blit(self._title, pos, None)

        height = 150
        for item in self._menu:
            if not item.position:
                item.position = ((surface.get_width() - item.get_width()) / 2,
                                 height)
            item.render(surface)
            height += item.get_height() + 30

    def _get_pressed(self, ev):
        for button in self._menu:
            if button.pressed(ev):
                return button.name
        return None

    def _do_day(self):
        from .day import DayScene
        SceneChangeEvent.post(scene=DayScene())

    def _do_load_level(self):
        from .load_level import LoadLevelScene
        SceneChangeEvent.post(scene=LoadLevelScene())

    def _do_help(self):
        from .help import HelpScene
        SceneChangeEvent.post(scene=HelpScene())

    def event(self, ev, gamestate):
        if ev.type == pgl.KEYDOWN:
            if ev.key in (pgl.K_q, pgl.K_ESCAPE):
                QuitEvent.post()
            elif ev.key == pgl.K_n:
                from .night import NightScene
                SceneChangeEvent.post(scene=NightScene())
            elif ev.key == pgl.K_d:
                self._do_day()
            elif ev.key == pgl.K_l:
                self._do_load_level()
            elif ev.key == pgl.K_h:
                self._do_help()
        elif ev.type == pgl.MOUSEBUTTONDOWN:
            pressed = self._get_pressed(ev)
            if pressed == 'load level':
                self._do_load_level()
            elif pressed == 'start game':
                self._do_day()
            elif pressed == 'help':
                self._do_help()
            elif pressed:
                print 'Pressed', pressed
