# Simple widgets
# This just unifies some logic.
# There is no implied container / window system (yet)

import pygame.locals as pgl

from .loader import loader
from .constants import FONTS
from .transforms import NullTransform


class Button(object):

    def __init__(self, size, name=None, pos=None, padding=10):
        self._size = size
        self._padding = padding
        self.position = pos
        self.name = name

    @property
    def position(self):
        return self._pos

    @position.setter
    def position(self, pos):
        self._pos = pos
        if pos is not None:
            self._min_x = pos[0] - self._padding
            self._max_x = pos[0] + self._size[0] + self._padding
            self._min_y = pos[1] - self._padding
            self._max_y = pos[1] + self._size[1] + self._padding

    def get_width(self):
        return self._size[0]

    def get_height(self):
        return self._size[1]

    def render(self, surface):
        pass

    def pressed(self, ev):
        if self._pos is None:
            # Unplaced buttons can't be pressed
            return False
        if ev.type == pgl.MOUSEBUTTONDOWN and ev.button == 1:
            if self._min_x < ev.pos[0] < self._max_x:
                if self._min_y < ev.pos[1] < self._max_y:
                    return True
        return False


class TextButton(Button):

    def __init__(self, text, colour, name=None, pos=None, padding=10):
        font = loader.load_font(FONTS['sans'], size=24)
        self._text = font.render(text, True, colour)
        super(TextButton, self).__init__(self._text.get_size(), name,
                                         pos, padding)

    def render(self, surface):
        surface.blit(self._text, self._pos, None)


class ImageButton(Button):

    def __init__(self, *imgparts, **kwargs):
        transform = kwargs.pop("transform", NullTransform())
        self._img = kwargs.pop("image", None)
        if self._img is None:
            self._img = loader.load_image(*imgparts, transform=transform)
        name = kwargs.get('name')
        pos = kwargs.get('pos')
        padding = kwargs.get('padding', 0)
        super(ImageButton, self).__init__(self._img.get_size(), name,
                                          pos, padding)

    def update_image(self, *imgparts, **kwargs):
        transform = kwargs.pop("transform", NullTransform())
        self._img = loader.load_image(*imgparts, transform=transform)

    def render(self, surface):
        surface.blit(self._img, self._pos, None)
